INumber

Struct INumber 

pub struct INumber(/* private fields */);
The INumber type represents a JSON number. It is decoupled from any specific representation, and internally uses several. There is no way to determine the internal representation: instead the caller is expected to convert the number using one of the fallible to_xxx functions and handle the cases where the number does not convert to the desired type.

Special floating point values (eg. NaN, Infinity, etc.) cannot be stored within an INumber.

Whilst INumber does not consider 2.0 and 2 to be different numbers (ie. they will compare equal) it does allow you to distinguish them using the method INumber::has_decimal_point(). That said, calling to_i32 on 2.0 will succeed with the value 2.

Small numbers — integers and short decimals alike — are stored inline without a heap allocation. Larger integers (i64/u64) and floating point values that are not short decimals are stored behind a pointer.

Implementations

Source

impl INumber

pub fn zero() -> Self

Returns the number zero (without a decimal point). Does not allocate.

pub fn one() -> Self

Returns the number one (without a decimal point). Does not allocate.

pub fn to_i64(&self) -> Option<i64>

Converts this number to an i64 if it can be represented exactly.

pub fn to_u64(&self) -> Option<u64>

Converts this number to a u64 if it can be represented exactly.

pub fn to_f64(&self) -> Option<f64>

Converts this number to an f64 if it can be represented exactly.

pub fn to_f32(&self) -> Option<f32>

Converts this number to an f32 if it can be represented exactly.

pub fn to_i32(&self) -> Option<i32>

Converts this number to an i32 if it can be represented exactly.

pub fn to_u32(&self) -> Option<u32>

Converts this number to a u32 if it can be represented exactly.

pub fn to_isize(&self) -> Option<isize>

Converts this number to an isize if it can be represented exactly.

pub fn to_usize(&self) -> Option<usize>

Converts this number to a usize if it can be represented exactly.

pub fn to_f64_lossy(&self) -> f64

Converts this number to an f64, potentially losing precision in the process.

pub fn to_f32_lossy(&self) -> f32

Converts this number to an f32, potentially losing precision in the process.

pub fn has_decimal_point(&self) -> bool

This allows distinguishing between 1.0 and 1 in the original JSON. Numeric operations will otherwise treat these two values as equivalent.