IObject

Struct IObject 

pub struct IObject(/* private fields */);
The IObject type is similar to a HashMap<IString, IValue>. As with the IArray, the length and capacity are stored inside the heap allocation. In addition, IObjects preserve the insertion order of their elements, in case that is important in the original JSON.

Removing from an IObject will disrupt the insertion order.

Implementations

Source

impl IObject

pub fn new() -> Self

Constructs a new empty IObject. Does not allocate.

pub fn with_capacity(cap: usize) -> Self

Constructs a new IObject with the specified capacity. At least that many entries can be added to the object without reallocating.

pub fn capacity(&self) -> usize

Returns the capacity of the object. This is the maximum number of entries the object can hold without reallocating.

pub fn len(&self) -> usize

Returns the number of entries currently stored in the object.

pub fn is_empty(&self) -> bool

Returns true if the object is empty.

pub fn reserve(&mut self, additional: usize)

Reserves space for at least this many additional entries.

pub fn entry<'a>(&'a mut self, key: impl Into<IString>) -> Entry<'a>

Returns a view of an entry within this object.

pub fn entry_or_clone<'a>(&'a mut self, key: &IString) -> Entry<'a>

Returns a view of an entry within this object, whilst avoiding cloning the key if the entry is already occupied.

pub fn keys(&self) -> impl Iterator<Item = &IString>

Returns an iterator over references to the keys in this object.

pub fn values(&self) -> impl Iterator<Item = &IValue>

Returns an iterator over references to the values in this object.

pub fn iter<'a>(&'a self) -> Iter<'a>

Returns an iterator over (&key, &value) pairs in this object.

pub fn values_mut(&mut self) -> impl Iterator<Item = &mut IValue>

Returns an iterator over mutable references to the values in this object.

pub fn iter_mut<'a>(&'a mut self) -> IterMut<'a>

Returns an iterator over (&key, &mut value) pairs in this object.

pub fn clear(&mut self)

Removes all entries from the object. The capacity is unchanged.

pub fn get_key_value(&self, k: impl ObjectIndex) -> Option<(&IString, &IValue)>

Looks up the specified key in this object and returns a (&key, &value) pair if found.

pub fn get_key_value_mut( &mut self, k: impl ObjectIndex, ) -> Option<(&IString, &mut IValue)>

Looks up the specified key in this object and returns a (&key, &mut value) pair if found.

pub fn get(&self, k: impl ObjectIndex) -> Option<&IValue>

Looks up the specified key in this object and returns a reference to the corresponding value if found.

pub fn get_mut(&mut self, k: impl ObjectIndex) -> Option<&mut IValue>

Looks up the specified key in this object and returns a mutable reference to the corresponding value if found.

pub fn contains_key(&self, k: impl ObjectIndex) -> bool

Returns true if the specified key exists in the object.

pub fn insert( &mut self, k: impl Into<IString>, v: impl Into<IValue>, ) -> Option<IValue>

Inserts a new value into this object with the specified key. If a value already existed at this key, that value is replaced and returend.

pub fn remove_entry(&mut self, k: impl ObjectIndex) -> Option<(IString, IValue)>

Removes the entry at the specified key, returning both the key and value if found.

pub fn remove(&mut self, k: impl ObjectIndex) -> Option<IValue>

Removes the entry at the specified key, returning the value if found.

pub fn shrink_to_fit(&mut self)

Shrinks the memory allocation used by the object such that its capacity becomes equal to its length.

pub fn retain(&mut self, f: impl FnMut(&IString, &mut IValue) -> bool)

Calls the specified function for each entry in the object. Each entry where the function returns false is removed from the object.

The function also has the ability to modify the values in-place.